@@ -3,9 +3,12 @@
 from core_exporters_app.components.exported_compressed_file.models import (
     ExportedCompressedFile,
 )
+from core_exporters_app.access_control.api import can_read
+from core_main_app.access_control.decorators import access_control
 
 
-def get_by_id(exported_compressed_file_id):
+@access_control(can_read)
+def get_by_id(exported_compressed_file_id, user):
     """Gets Exported compressed file with the given id
 
     Args:
